"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const common_1 = require("../common");
const json_schema_faker_1 = __importDefault(require("json-schema-faker"));
const types_1 = require("../types");
function createPubSubdata(input, stringify = true) {
    const message = json_schema_faker_1.default.generate(types_1.PubSubMessage);
    const data = Buffer.from(stringify ? JSON.stringify(input) : input).toString('base64');
    return {
        ...message,
        data,
    };
}
describe('common', () => {
    it('should handle simple PubSub messages', async () => {
        const message = createPubSubdata('hello-world', false);
        const handler = jest.fn();
        await (0, common_1.handlePubSubMessage)({
            message,
            handler,
            parseJson: false,
            log: {},
        });
        expect(handler).toHaveBeenCalledWith({
            message,
            data: 'hello-world',
            log: {},
        });
    });
    it('should handle JSON PubSub messages', async () => {
        const message = createPubSubdata({ name: 'Simen' });
        const handler = jest.fn();
        await (0, common_1.handlePubSubMessage)({
            message,
            handler,
            parseJson: true,
            log: {},
        });
        expect(handler).toHaveBeenCalledWith({
            message,
            data: { name: 'Simen' },
            log: {},
        });
    });
    it('should pass context', async () => {
        const message = createPubSubdata('');
        const handler = jest.fn();
        await (0, common_1.handlePubSubMessage)({
            message,
            handler,
            context: { hello: 'there' },
            log: {},
        });
        expect(handler).toHaveBeenCalledWith({
            message,
            data: '',
            context: { hello: 'there' },
            log: {},
        });
    });
});
//# sourceMappingURL=common.test.js.map